TextAnalysisExtensionsOnString extension

Extension methods on term that exposes methods analysing and tokenizing text.

on

Properties

diphtongs → List<String>

Available on String, provided by the TextAnalysisExtensionsOnString extension

Returns all the diphtongs in the String.
no setter
termCount → int

Available on String, provided by the TextAnalysisExtensionsOnString extension

Returns the number of individual terms in the String.
no setter
triptongs → List<String>

Available on String, provided by the TextAnalysisExtensionsOnString extension

Returns all the diphtongs in the String.
no setter
vowelDipthongAndTriptongCount → int

Available on String, provided by the TextAnalysisExtensionsOnString extension

Returns the number of single vowels, diphtongs and triptongs in the String.
no setter
vowels → List<String>

Available on String, provided by the TextAnalysisExtensionsOnString extension

Returns all the vowels in the String.
no setter
words → List<String>

Available on String, provided by the TextAnalysisExtensionsOnString extension

Returns all the words in the String.
no setter

Methods

normalizeHyphens() → String

Available on String, provided by the TextAnalysisExtensionsOnString extension

Replaces all dashes and hyphens (U+2011 through U+2014) with a standard hyphen (U+2011).
normalizeQuotes() → String

Available on String, provided by the TextAnalysisExtensionsOnString extension

Replaces all double quote characters with U+0022, and single quote characters with +U0027
normalizeWhitespace() → String

Available on String, provided by the TextAnalysisExtensionsOnString extension

Replace all white-space sequences with single space and trim.
removeEnclosingQuotes() → String

Available on String, provided by the TextAnalysisExtensionsOnString extension

Trims all forms of quotation marks from start of the String.
removePossessives() → String

Available on String, provided by the TextAnalysisExtensionsOnString extension

Removes all posessive apostropes.
removeQuotes() → String

Available on String, provided by the TextAnalysisExtensionsOnString extension

Removes all quote marks from the string, except where within a word or where it is a apostrophe preceded by n "s" or "S" (possessive plural).
splitAtWhitespace() → List<String>

Available on String, provided by the TextAnalysisExtensionsOnString extension

Split the String at (one or more) white-space characters.