TermCoOccurrenceGraphMixin class abstract

Mixin class that implements TermCoOccurrenceGraph.termFrequency, TermCoOccurrenceGraph.termDegree and TermCoOccurrenceGraph.keyWordScore.

Classes that mix in TermCoOccurrenceGraphMixin must override:

Implemented types
Implementers

Properties

coOccurrenceGraph → Map<String, List<int>>
The map that holds the matrix of terms.
no setter
hashCode → int
The hash code for this object.
no setterinherited
keywords → Iterable<List<String>>
The collection of keywords, each as a list of terms.
no setterinherited
keywordScores → Map<String, double>
Returns a mapping of the keywords to their RAKE scores.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terms → List<String>
The unique terms in the coOccurrenceGraph.
no setter
uniqueTerms → Set<String>
The set of unique terms in the co-occurrence graph.
no setterinherited

Methods

keyWordScore(List<String> keyWord) → double
The RAKE keyword score for the keyWord
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
termDegree(String term) → int
The word degree of the term
override
termFrequency(String term) → int
The word frequency for the term.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited