TextDocumentMixin class abstract

Implemented types
Implementers

Constructors

TextDocumentMixin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
keywords → TermCoOccurrenceGraph
The unique keywords in the document mapped to their RAKE keyword score in a TermCoOccurrenceGraph.
no setterinherited
nGrams → List<String>
A collection of n-grams from the terms in the document.
no setterinherited
paragraphs → List<String>
All the paragraphs in the sourceText.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentences → List<String>
All the sentences in the sourceText.
no setterinherited
sourceText → String
Returns the source text associated with the document.
no setterinherited
syllableCount → int
The total number of syllables in the document.
no setterinherited
terms → List<String>
All the words in the sourceText.
no setterinherited
tokens → List<Token>
The tokens extracted from sourceText.
no setterinherited
zones → Iterable<String>?
A collection of the names of the zones in document that are to be tokenized.
no setterinherited

Methods

averageSentenceLength() → int
The average number of words in sentences.
override
averageSyllableCount() → double
The average number of syllables per word in terms.
override
fleschKincaidGradeLevel() → int
Returns the readability score of sourceText on a U.S. school grade level (Flesch-Kincaid Grade Level test).
override
fleschReadingEaseScore() → double
Returns the Flesch reading ease score of the sourceText on a 100-point scale.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
wordCount() → int
The number of words in the sourceText.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited