Token class

A Token represents a term (word) present in a text source:

  • term is the term that will be looked up in the index;
  • termPosition is the zero-based position of the term in an ordered list of all the terms in the source text;
  • n is the number of terms in the n-gram; and
  • zone is the nullable name of the zone the term is in.

Constructors

Token(String term, int n, int termPosition, [String? zone])
Instantiates a Token instance:
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
n → int
The number of terms in a n-gram.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
term → String
A term extracted text by a TextAnalyzer.
final
termPosition → int
The zero-based position of the term in an ordered list of all the terms in the source text.
final
zone → String?
The name of the zone (e.g. field name in a JSON document) that the term is in.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Compares whether:
override

Constants

empty → const Token
Instantiates Token instance.